/**
 * Generates a URL-friendly slug from a string
 * Handles special characters, accents, apostrophes, and spaces
 */
export function generateSlug(text: string): string {
  return (
    text
      .toLowerCase()
      // Replace ampersands with "et"
      .replace(/&/g, "et")
      // Replace apostrophes with hyphens
      .replace(/'/g, "-")
      // Replace spaces with hyphens
      .replace(/\s+/g, "-")
      // Remove accents
      .normalize("NFD")
      .replace(/[\u0300-\u036f]/g, "")
      // Replace multiple hyphens with a single hyphen
      .replace(/-+/g, "-")
      // Remove any remaining special characters
      .replace(/[^\w-]/g, "")
  )
}

/**
 * Normalizes a slug for comparison
 * Less strict than generateSlug, used for matching existing slugs
 */
export function normalizeSlug(slug: string): string {
  return (
    decodeURIComponent(slug)
      .toLowerCase()
      // Replace ampersands with "et"
      .replace(/&/g, "et")
      // Replace apostrophes with hyphens
      .replace(/'/g, "-")
      // Remove accents
      .normalize("NFD")
      .replace(/[\u0300-\u036f]/g, "")
      // Replace multiple hyphens with a single hyphen
      .replace(/-+/g, "-")
  )
}
